.. :changelog:

Release History
===============

Unreleased
----------

* fix issue with trailing null byte padding in answer
* more robust parsing of responses
* add logging

0.0.2
-----

* add TLS support


0.0.1
-----

Inital Release
